#
# spec file for package python-pulsectl
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-pulsectl
Version:        20.2.4 
Release:        lp152.1.1
Summary:        Python high-level interface and ctypes-based bindings for PulseAudio (libpulse)
License:        MIT
Group:          Development/Languages/Python
URL:            http://github.com/mk-fg/python-pulse-control
Source:         https://files.pythonhosted.org/packages/source/p/pulsectl/pulsectl-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       pulseaudio >= 5.0
Requires:       python-setuptools
BuildArch:      noarch
%if %{with test}
BuildRequires:  libpulse-devel >= 5.0
BuildRequires:  pulseaudio
BuildRequires:  pulseaudio-utils
%endif
%python_subpackages

%description
Python (3.x and 2.x) high-level interface and ctypes-based bindings for
PulseAudio (libpulse), mostly focused on mixer-like controls and
introspection-related operations (as opposed to e.g. submitting sound samples to
play, player-like client).

%prep
%setup -q -n pulsectl-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_exec -m unittest pulsectl.tests.all
%endif

%files %{python_files}
%license COPYING
%doc CHANGES.rst README.rst
%{python_sitelib}/*

%changelog
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 20.2.4
  * Add pulse.get_card_by_name() wrapper [#38].
  * Expose "corked" bool attr in PulseSinkInputInfo and PulseSourceOutputInfo [#37].
* Mon Jan 20 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 20.1.2
  * add pulse.play_sample() - server-side stored sample playback
  * Add pulse.get_peak_sample() func for getting volume peak within timespan
* Wed Jun  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 18.12.5
  * pulse.connect() can now be used to reconnect to same server
  * _pulse_op_cb: check connected state instead of _loop_stop
  * _pulse_op_cb: fix hang if daemon dies
  * tests: use "-F /dev/stdin" instead of -C for dummy pulse instance
  * Add pulsectl.lookup util submodule
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Jan  5 2018 alarrosa@suse.com
- Update to version 17.12.2
  * Use pa_card_profile_info2 / profiles2 introspection API.
  * Only adds one "available" property to PulseCardProfileInfo.
    Requires pulseaudio/libpulse 5.0+.
* Fri Nov 10 2017 alarrosa@suse.com
- Initial release of python-pulsectl 17.9.3
